@@ -6,6 +6,7 @@ from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
+from Products.Archetypes.interfaces import IBaseObject
 from Products.Archetypes.interfaces.field import IImageField
 from Products.Archetypes.Field import ImageField
 from Products.CMFCore.utils import getToolByName
@@ -563,8 +564,14 @@ class TinyMCE(SimpleItem):
 
     security.declareProtected('View', 'getContentType')
     def getContentType(self, object=None, fieldname=None):
-        if hasattr(aq_base(object), 'getContentType'):
-            return object.getContentType(fieldname)
+        context = aq_base(object)
+        if IBaseObject.providedBy(context):
+            if fieldname is None:
+                field = context.getPrimaryField()
+            else:
+                field = context.getField(fieldname) or getattr(context, fieldname, None)
+            if field and hasattr(aq_base(field), 'getContentType'):
+                return field.getContentType(context)
         return 'text/html'
 
     security.declareProtected('View', 'getConfiguration')
